==> kdesdk-4.4.3.tar.xz: kdesdk-4.4.3/umbrello/umbrello/codegenerators/ada/adawriter.h <==
/***************************************************************************
                          adawriter.h  -  description
                             -------------------
    Based on javawriter.h by Luis De la Parra Blum
    begin                : Sat Dec 14 2002
    copyright            : (C) 2002 by Oliver Kellogg
    email                : okellogg@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADAWRITER_H
#define ADAWRITER_H

#include "simplecodegenerator.h"

class UMLAssociation;
class UMLOperation;
class QTextStream;

/**
 * Class AdaWriter is a code generator for UMLClassifier objects.
 * Create an instance of this class, and feed it a UMLClassifier when
 * calling writeClass and it will generate an Ada package spec for
 * that concept.
 */
class AdaWriter : public SimpleCodeGenerator 
{
    Q_OBJECT
public:

    /**
     * Basic Constructor
     */
    AdaWriter ();

    /**
     * Empty Destructor
     */
    virtual ~AdaWriter ();

    /**
     * Call this method to generate Ada code for a UMLClassifier.
     * @param c the class to generate code for
     */
    virtual void writeClass (UMLClassifier *c);

    /**
     * returns "Ada"
     */
    virtual Uml::Programming_Language getLanguage();

    QStringList defaultDatatypes();

    /**
     * Check whether the given string is a reserved word for the
     * language of this code generator.
     *
     * @param rPossiblyReservedKeyword  The string to check.
     * @return true if the keyword is reserved
     */
    virtual bool isReservedKeyword(const QString & rPossiblyReservedKeyword);

    /**
     * Get list of reserved keywords.
     */
    virtual const QStringList reservedKeywords() const;

private:

    /**
     * Write one operation.
     * @param op the class for which we are generating code
     * @param ada the stream associated with the output file
     */
    void writeOperation (UMLOperation *op, QTextStream &ada, bool is_comment = false);

    /**
     * Compute the type and role name from the given association.
     *
     * @param c         The UMLClassifier for which code is being generated.
     * @param a         The UMLAssociation to analyze.
     * @param typeName  Return value: type name.
     * @param roleName  Return value: role name.
     */
    void computeAssocTypeAndRole (UMLClassifier *c,
                                  UMLAssociation *a,
                                  QString& typeName, QString& roleName);

    bool isOOClass (UMLClassifier *c);

    QString className(UMLClassifier *c, bool inOwnScope = true);

    QString packageName(UMLPackage *p);

    static const QString defaultPackageSuffix;

};

#endif // ADAWRITER_H

==> kdesdk-4.5.5.tar.xz: kdesdk-4.5.5/umbrello/umbrello/codegenerators/ada/adawriter.h <==
/***************************************************************************
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   copyright (C) 2002    Oliver Kellogg <okellogg@users.sourceforge.net> *
 *   copyright (C) 2003-2010                                               *
 *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
 ***************************************************************************/

#ifndef ADAWRITER_H
#define ADAWRITER_H

#include "simplecodegenerator.h"

class UMLAssociation;
class UMLOperation;
class QTextStream;

/**
 * Class AdaWriter is a code generator for UMLClassifier objects.
 * Based on javawriter.h by Luis De la Parra Blum.
 * Create an instance of this class, and feed it a UMLClassifier when
 * calling writeClass and it will generate an Ada package spec for
 * that concept.
 */
class AdaWriter : public SimpleCodeGenerator 
{
    Q_OBJECT
public:

    AdaWriter();
    virtual ~AdaWriter();

    virtual void writeClass(UMLClassifier *c);

    virtual Uml::Programming_Language language() const;

    QStringList defaultDatatypes();

    virtual bool isReservedKeyword(const QString & rPossiblyReservedKeyword);

    virtual QStringList reservedKeywords() const;

private:

    void writeOperation(UMLOperation *op, QTextStream &ada, bool is_comment = false);

    void computeAssocTypeAndRole(UMLClassifier *c,
                                 UMLAssociation *a,
                                 QString& typeName, QString& roleName);

    bool isOOClass(UMLClassifier *c);

    QString className(UMLClassifier *c, bool inOwnScope = true);

    QString packageName(UMLPackage *p);

    static const QString defaultPackageSuffix;

};

#endif // ADAWRITER_H
